pub struct verifyCall {
pub signer: Address,
pub hash: FixedBytes<32>,
pub signature: Bytes,
}Expand description
@notice Verifies a signer against a Tempo signature (secp256k1, P256, WebAuthn).
@param signer The input address verified against the recovered signer
@param hash The message hash that was signed
@param signature The encoded signature (see Tempo Transaction spec for formats)
@return True if the input address signed, false otherwise. Reverts on invalid signatures.
Function with signature verify(address,bytes32,bytes) and selector 0x1a86b550.
function verify(address signer, bytes32 hash, bytes calldata signature) external view returns (bool);Fields
signer: Addresshash: FixedBytes<32>signature: BytesTrait Implementations
Sourceimpl Clone for verifyCall
impl Clone for verifyCall
Sourcefn clone(&self) -> verifyCall
fn clone(&self) -> verifyCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for verifyCall
impl Debug for verifyCall
Sourceimpl<'de> Deserialize<'de> for verifyCall
impl<'de> Deserialize<'de> for verifyCall
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonAbiExt for verifyCall
impl JsonAbiExt for verifyCall
Sourceimpl PartialEq for verifyCall
impl PartialEq for verifyCall
Sourcefn eq(&self, other: &verifyCall) -> bool
fn eq(&self, other: &verifyCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for verifyCall
impl Serialize for verifyCall
Sourceimpl SolCall for verifyCall
impl SolCall for verifyCall
Sourcetype Parameters<'a> = (Address, FixedBytes<32>, Bytes)
type Parameters<'a> = (Address, FixedBytes<32>, Bytes)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<verifyCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<verifyCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding [TokenSeq] type.
Sourcetype ReturnTuple<'a> = (Bool,)
type ReturnTuple<'a> = (Bool,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<verifyCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<verifyCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding [TokenSeq] type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
ABI encode the call to the given buffer with its selector.
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
ABI encode the call’s return value.
impl Eq for verifyCall
impl StructuralPartialEq for verifyCall