pub struct verifyKeychainAdminCall {
pub account: Address,
pub hash: FixedBytes<32>,
pub signature: Bytes,
}Expand description
@notice Verifies whether a keychain signature was produced by a root or active admin key.
@param account The expected embedded root account
@param hash The message hash that was signed
@param signature The encoded keychain signature
@dev Does not compare the inner signature type against the stored key type.
@return True if the recovered key is account or an active admin key on account.
Function with signature verifyKeychainAdmin(address,bytes32,bytes) and selector 0x5f6fc5b7.
function verifyKeychainAdmin(address account, bytes32 hash, bytes calldata signature) external view returns (bool);Fields
account: Addresshash: FixedBytes<32>signature: BytesTrait Implementations
Sourceimpl Clone for verifyKeychainAdminCall
impl Clone for verifyKeychainAdminCall
Sourcefn clone(&self) -> verifyKeychainAdminCall
fn clone(&self) -> verifyKeychainAdminCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for verifyKeychainAdminCall
impl Debug for verifyKeychainAdminCall
Sourceimpl<'de> Deserialize<'de> for verifyKeychainAdminCall
impl<'de> Deserialize<'de> for verifyKeychainAdminCall
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for verifyKeychainAdminCall
Sourceimpl JsonAbiExt for verifyKeychainAdminCall
impl JsonAbiExt for verifyKeychainAdminCall
Sourceimpl PartialEq for verifyKeychainAdminCall
impl PartialEq for verifyKeychainAdminCall
Sourcefn eq(&self, other: &verifyKeychainAdminCall) -> bool
fn eq(&self, other: &verifyKeychainAdminCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for verifyKeychainAdminCall
impl Serialize for verifyKeychainAdminCall
Sourceimpl SolCall for verifyKeychainAdminCall
impl SolCall for verifyKeychainAdminCall
Sourceconst SIGNATURE: &'static str = "verifyKeychainAdmin(address,bytes32,bytes)"
const SIGNATURE: &'static str = "verifyKeychainAdmin(address,bytes32,bytes)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Address, FixedBytes<32>, Bytes)
type Parameters<'a> = (Address, FixedBytes<32>, Bytes)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<verifyKeychainAdminCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<verifyKeychainAdminCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding [TokenSeq] type.
Sourcetype ReturnTuple<'a> = (Bool,)
type ReturnTuple<'a> = (Bool,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<verifyKeychainAdminCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<verifyKeychainAdminCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding [TokenSeq] type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
ABI encode the call to the given buffer with its selector.
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
ABI encode the call’s return value.
impl StructuralPartialEq for verifyKeychainAdminCall